package com.younike.system.service.impl;

import com.younike.system.domain.vo.ServerTimesVO;
import com.younike.system.mapper.MerchantServerTimeMapper;
import com.younike.system.service.IMerchantServerTimeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 服务人员服务时间Service业务层处理
 *
 * @author elev
 * @date 2022-01-07
 */
@Service
public class MerchantServerTimeServiceImpl implements IMerchantServerTimeService {
    @Autowired
    private MerchantServerTimeMapper serverTimeMapper;

    /**
     * 查询服务人员服务时间
     *
     * @param serverId 服务人员服务时间主键
     * @return 服务人员服务时间
     */
    @Override
    public ServerTimesVO selectServerTimeByServerId(Long serverId) {
        return serverTimeMapper.selectServerTimeByServerId(serverId);
    }

    /**
     * 查询服务人员服务时间列表
     *
     * @param serverTime 服务人员服务时间
     * @return 服务人员服务时间
     */
    @Override
    public List<ServerTimesVO> selectServerTimeList(ServerTimesVO serverTime) {
        return serverTimeMapper.selectServerTimeList(serverTime);
    }

    /**
     * 新增服务人员服务时间
     *
     * @param serverTime 服务人员服务时间
     * @return 结果
     */
    @Override
    public int insertServerTime(ServerTimesVO serverTime) {
//        serverTime.setCreateTime(LocalDateTime.now());
        return serverTimeMapper.insertServerTime(serverTime);
    }

    /**
     * 修改服务人员服务时间
     *
     * @param serverTime 服务人员服务时间
     * @return 结果
     */
    @Override
    public int updateServerTime(ServerTimesVO serverTime) {
//        serverTime.setUpdateTime(LocalDateTime.now());
        return serverTimeMapper.updateServerTime(serverTime);
    }

    /**
     * 批量删除服务人员服务时间
     *
     * @param serverIds 需要删除的服务人员服务时间主键
     * @return 结果
     */
    @Override
    public int deleteServerTimeByServerIds(Long[] serverIds) {
        return serverTimeMapper.deleteServerTimeByServerIds(serverIds);
    }

    /**
     * 删除服务人员服务时间信息
     *
     * @param serverId 服务人员服务时间主键
     * @return 结果
     */
    @Override
    public int deleteServerTimeByServerId(Long serverId)
    {
        return serverTimeMapper.deleteServerTimeByServerId(serverId);
    }
}
